var referenceId = Math.random().toString(35).slice(2);
function buildPaymentRequest(payments, amount) {
	const paymentRequest = payments.paymentRequest({
		countryCode: "US",
		currencyCode: "USD",
		total: {
			amount: amount,
			label: "Total",
		},
	});
	return paymentRequest;
}

async function initializeCashApp(payments, amount) {
	const paymentRequest = buildPaymentRequest(payments, amount);
	const cashAppPay = await payments.cashAppPay(paymentRequest, {
		redirectURL: window.location.href,
		referenceId: referenceId,
	});
	// const cashAppPayButtonTarget = document.getElementById("cash-app-pay");
	// await cashAppPay.attach(cashAppPayButtonTarget);
	await cashAppPay.attach("#cash-app-pay");
	document.getElementById("cash-app-spinner").style.display = "none";
	return cashAppPay;
}

async function loadCashAppPay() {
	var amount = document.getElementById("amount")?.value;
	var environment = document.getElementById("sq_environment")?.value;
	let locationId = document.getElementById("sq_location")?.value;
	console.log(
		`DOMContentLoaded: amount: ${amount}, environment: ${environment}, locationId: ${locationId}`
	);

	if (!amount || !environment || !locationId) {
		document.getElementById("payment-status-container").innerHTML =
			"<p>Missing required parameters. Finish setting up properly first</p>";
		document.getElementById("cash-app-spinner").style.display = "none";
		throw new Error("Missing required parameters");
	}

	if (!window.Square) {
		document.getElementById("payment-status-container").innerHTML =
			"<p>Square.js failed to load properly</p>";
		document.getElementById("cash-app-spinner").style.display = "none";
		throw new Error("Square.js failed to load properly");
	}

	let payments;
	let appId;
	if (environment === "sandbox") {
		appId = "sandbox-sq0idb-aYar6zHAvIrhMgeKHqKxlQ";
	} else {
		appId = "sq0idp-ZXTjnM5LRS7w5XE9MaRzvQ";
	}

	try {
		console.log(appId, locationId);
		payments = Square.payments(appId, locationId);
		console.log("payments", payments);
	} catch (error) {
		console.error("window.Square.payments Error:", error);
		document.getElementById("cash-app-spinner").style.display = "none";
		document.getElementById("payment-status-container").innerHTML =
			"<p>Square Tokenization failed<br>" + error + " window.Square.payments</p>";
		// throw new Error(error);
		return;
	}

	let cashAppPay;
	try {
		console.log(amount, payments);
		cashAppPay = await initializeCashApp(payments, amount);
	} catch (error) {
		console.error("initializeCashApp Error:", error);
		document.getElementById("payment-status-container").innerHTML =
			"<p>Initializing Cash App Pay failed<br>" + error + "</p>";
		document.getElementById("cash-app-spinner").style.display = "none";
	}
	if (cashAppPay) {
		console.log("initializeCashApp", cashAppPay);

		try {
			cashAppPay.addEventListener("ontokenization", async (event) => {
				console.debug("ontokenization", event);
				const { tokenResult, error } = event.detail;

				if (error) {
					console.error(error);
					document.getElementById("payment-status-container").innerHTML =
						"<p>Square Tokenization Error<br>" + error + "</p>";
					document.getElementById("cash-app-spinner").style.display = "none";
					throw new Error(error);
				} else if (tokenResult.status === "OK") {
					document.getElementById("payment_token").value = tokenResult.token;
					document.getElementById("cash-app-spinner").style.display = "none";
				} else {
					let errorMessage = `Tokenization failed with status: ${tokenResult.status}`;
					if (tokenResult.errors) {
						errorMessage += ` and errors: ${JSON.stringify(tokenResult.errors)}`;
					}
					console.error(errorMessage);
					document.getElementById("payment-status-container").innerHTML =
						"<p>Square failure after tokenization<br>" + errorMessage + "</p>";
					document.getElementById("cash-app-spinner").style.display = "none";
					throw new Error(errorMessage);
				}
			});
			// cashAppPay.addEventListener("ontokenization", async function ({ detail }) {
			// 	const tokenResult = detail.tokenResult;
			// 	if (tokenResult.status === "OK") {
			// 		// change value of hidden input to token
			// 		document.getElementById("payment_token").value = tokenResult.token;
			// 		document.getElementById("cash-app-spinner").style.display = "none";
			// 	} else {
			// 		let errorMessage = `Tokenization failed with status: ${tokenResult.status}`;
			// 		if (tokenResult.errors) {
			// 			errorMessage += ` and errors: ${JSON.stringify(tokenResult.errors)}`;
			// 		}
			// 		console.error(errorMessage);
			// 		document.getElementById("payment-status-container").innerHTML =
			// 			"<p>Square Tokenization failed<br>" + errorMessage + "</p>";
			// 		document.getElementById("cash-app-spinner").style.display = "none";
			// 		throw new Error(errorMessage);
			// 	}
			// });
		} catch (error) {
			console.error(error);
			document.getElementById("payment-status-container").innerHTML =
				"<p>Square ontokenization Error<br>" + error + "</p>";
			document.getElementById("cash-app-spinner").style.display = "none";
			throw new Error(error);
		}
	}
}

window.onload = function () {
	(function () {
		var payment_method_cash_app_pay = document.querySelector(
			"li.payment_method_cash-app-pay"
		);
		if (payment_method_cash_app_pay) {
			loadCashAppPay();
		} else {
			console.debug("payment_method_cash-app-pay not found");
			setTimeout(arguments.callee, 1000); // call myself again in 1000 msecs
		}
	})();
};
