<?php

declare(strict_types=1);

namespace Square\Models;

use Exception;
use Square\ApiHelper;

/**
 * Defines whether the event was generated by the Square Point of Sale.
 */
class LoyaltyEventSource
{
    /**
     * The event is generated by the Square Point of Sale (POS).
     */
    public const SQUARE = 'SQUARE';

    /**
     * The event is generated by something other than the Square Point of Sale that used the Loyalty API.
     */
    public const LOYALTY_API = 'LOYALTY_API';

    private const _ALL_VALUES = [self::SQUARE, self::LOYALTY_API];

    /**
     * Ensures that all the given values are present in this Enum.
     *
     * @param array|null|string $value Value or a list of values to be checked
     *
     * @return array|null|string Input value(s), if all are a part of this Enum
     *
     * @throws Exception Throws exception if any given value is not in this Enum
     */
    public static function checkValue($value)
    {
        ApiHelper::checkValueInEnum($value, self::class, self::_ALL_VALUES);
        return $value;
    }
}
